@@ -67,7 +67,7 @@ static bool silentUpdate = false;
 
 // Global tables of foldernames is different languages
 // For now: 0->English, 1->German
-static QMap<KFolderTreeItem::Type,QString> folderNames[2];
+static QMap<KFolderTreeItem::Type,QString> folderNames[4];
 
 //-----------------------------------------------------------------------------
 KMGroupware::KMGroupware( QObject* parent, const char* name ) :
@@ -125,7 +125,7 @@ void KMGroupware::readConfig()
   }
 
   mFolderLanguage = options.readNumEntry( "FolderLanguage", 0 );
-  if( mFolderLanguage > 1 ) mFolderLanguage = 0; // Just for safety
+  if( mFolderLanguage > 3 ) mFolderLanguage = 0; // Just for safety
 
   QString parentName( options.readEntry("GroupwareFolder") );
   KMFolder* folderParent = kernel->folderMgr()->findIdString( parentName );
@@ -235,18 +235,9 @@ QString KMGroupware::folderName( KFolderTreeItem::Type type, int language ) cons
   static bool folderNamesSet = false;
   if( !folderNamesSet ) {
     folderNamesSet = true;
-    /*
-      Logical (enum)     English         German
-      ------------------------------------------------------
-      Contacts           Contacts        Kontakte
-      Calendar           Calendar        Kalender
-      Notes              Notes           Notizen
-      Tasks              Tasks           Aufgaben
-      Inbox              inbox           Posteingang
-      Outbox             outbox          Postausgang
-    */
     /* NOTE: If you add something here, you also need to update
        GroupwarePage in configuredialog.cpp */
+
     // English
     folderNames[0][KFolderTreeItem::Calendar] = QString::fromLatin1("Calendar");
     folderNames[0][KFolderTreeItem::Contacts] = QString::fromLatin1("Contacts");
@@ -259,9 +250,21 @@ QString KMGroupware::folderName( KFolderTreeItem::Type type, int language ) cons
     folderNames[1][KFolderTreeItem::Contacts] = QString::fromLatin1("Kontakte");
     folderNames[1][KFolderTreeItem::Notes] = QString::fromLatin1("Notizen");
     folderNames[1][KFolderTreeItem::Tasks] = QString::fromLatin1("Aufgaben");
+
+    // French
+    folderNames[2][KFolderTreeItem::Calendar] = QString::fromLatin1("Calendrier");
+    folderNames[2][KFolderTreeItem::Tasks] = QString::fromLatin1("Tches");
+    folderNames[2][KFolderTreeItem::Contacts] = QString::fromLatin1("Contacts");
+    folderNames[2][KFolderTreeItem::Notes] = QString::fromLatin1("Notes");
+
+    // Dutch
+    folderNames[3][KFolderTreeItem::Calendar] = QString::fromLatin1("Agenda");
+    folderNames[3][KFolderTreeItem::Tasks] = QString::fromLatin1("Taken");
+    folderNames[3][KFolderTreeItem::Contacts] = QString::fromLatin1("Contactpersonen");
+    folderNames[3][KFolderTreeItem::Notes] = QString::fromLatin1("Notities");
   }
 
-  if( language == -1 ) return folderNames[mFolderLanguage][type];
+  if( language < 0 || language > 3 ) return folderNames[mFolderLanguage][type];
   else return folderNames[language][type];
 }
 
@@ -770,6 +773,8 @@ void KMGroupware::setupActions()
 		 mMainWin->actionCollection(), "file_korganizerexport_ical" );
     new KAction( i18n("Export vCal"), 0, mKOrgPart, SLOT(slotExportVCalendar()),
 		 mMainWin->actionCollection(), "file_korganizerexport_vcal" );
+    new KAction( i18n("Export Web Page.."), "webexport", 0, mKOrgPart, SLOT(slotExportWebCalendar()),
+		 mMainWin->actionCollection(), "file_korganizerexport_web" );
     new KAction( i18n("delete completed To-Dos","Purge Completed To-Dos"), 0, mKOrgPart,
 		 SLOT(slotPurgeCompleted()), mMainWin->actionCollection(),
 		 "file_korganizerpurge_completed" );
@@ -843,6 +848,11 @@ void KMGroupware::setupActions()
 		 mMainWin->actionCollection(), "settings_korganizerdatetime" );
     new KAction( i18n("Edit Filters"), 0, mKOrgPart, SLOT(slotEditFilters()),
 		 mMainWin->actionCollection(), "settings_korganizeredit_filters" );
+    KToggleAction* ta =
+      new KToggleAction( i18n("Show Filter"), 0, mMainWin->actionCollection(),
+			 "settings_korganizershow_filter");
+    connect( ta, SIGNAL( toggled( bool ) ),
+	     mKOrgPart, SLOT( slotToggleFilterView( bool ) ) );
     new KAction( i18n("Edit Categories"), 0, mKOrgPart, SLOT(slotShowCategoryEditDialog()),
 		 mMainWin->actionCollection(), "settings_korganizeredit_categories" );
 
