@@ -399,7 +399,7 @@ QWidget* KMGroupwareWizard::createLanguagePage()
   mLanguageCombo = new QComboBox( false, rightSide );
 
   QStringList lst;
-  lst << i18n("English") << i18n("German");
+  lst << i18n("English") << i18n("German") << i18n("French") << i18n("Dutch");
   mLanguageCombo->insertStringList( lst );
 
   setLanguage( 0, false );
@@ -502,24 +502,25 @@ void KMGroupwareWizard::next()
   QWizard::next();
 }
 
-static bool checkSubfolders( KMFolderDir* dir, KMGroupware* gw, int language )
+static inline bool checkSubfolders( KMFolderDir* dir, const KMGroupware& gw,
+				    int language )
 {
-  return dir->hasNamedFolder( gw->folderName( KFolderTreeItem::Inbox, language ) ) &&
-    dir->hasNamedFolder( gw->folderName( KFolderTreeItem::Calendar, language ) ) &&
-    dir->hasNamedFolder( gw->folderName( KFolderTreeItem::Contacts, language ) ) &&
-    dir->hasNamedFolder( gw->folderName( KFolderTreeItem::Notes, language ) ) &&
-    dir->hasNamedFolder( gw->folderName( KFolderTreeItem::Tasks, language ) );
+  return dir->hasNamedFolder( gw.folderName( KFolderTreeItem::Inbox, language ) ) &&
+    dir->hasNamedFolder( gw.folderName( KFolderTreeItem::Calendar, language ) ) &&
+    dir->hasNamedFolder( gw.folderName( KFolderTreeItem::Contacts, language ) ) &&
+    dir->hasNamedFolder( gw.folderName( KFolderTreeItem::Notes, language ) ) &&
+    dir->hasNamedFolder( gw.folderName( KFolderTreeItem::Tasks, language ) );
 }
 
 void KMGroupwareWizard::guessExistingFolderLanguage()
 {
   KMFolderDir* dir = folder()->child();
-  KMGroupware* gw = &(KMKernel::self()->groupware());
-
-  if(  checkSubfolders( dir, gw, 0 ) ) {
+  if( !dir ) {
+    setLanguage( 0, false );
+  } else if( checkSubfolders( dir, KMKernel::self()->groupware(), 0 ) ) {
     // Check English
     setLanguage( 0, true );
-  } else if( checkSubfolders( dir, gw, 1 ) ) {
+  } else if( checkSubfolders( dir, KMKernel::self()->groupware(), 1 ) ) {
     // Check German
     setLanguage( 1, true );
   } else {
